@@ -23,8 +23,8 @@ test_that("using loo.cores is deprecated", {
 })
 
 test_that("loo and waic results haven't changed", {
-  expect_equal_to_reference(loo1, "loo.rds")
-  expect_equal_to_reference(waic1, "waic.rds")
+  expect_equal_to_reference(loo1, "reference-results/loo.rds")
+  expect_equal_to_reference(waic1, "reference-results/waic.rds")
 })
 
 test_that("loo with cores=1 and cores=2 gives same results", {
@@ -82,10 +82,14 @@ test_that("loo returns object with correct structure", {
   expect_named(loo1$diagnostics, c("pareto_k", "n_eff"))
   expect_equal(dimnames(loo1$estimates)[[1]], c("elpd_loo", "p_loo", "looic"))
   expect_equal(dimnames(loo1$estimates)[[2]], c("Estimate", "SE"))
-  expect_equal(colnames(loo1$pointwise), c("elpd_loo", "mcse_elpd_loo", "p_loo", "looic"))
+  expect_equal(colnames(loo1$pointwise), c("elpd_loo", "mcse_elpd_loo", "p_loo", "looic", "influence_pareto_k"))
   expect_equal(dim(loo1), dim(LLmat))
 })
 
+test_that("two pareto k values are equal", {
+  expect_identical(loo1$pointwise[,"influence_pareto_k"], loo1$diagnostics$pareto_k)
+})
+
 test_that("loo.array and loo.matrix give same result", {
   l2 <- suppressWarnings(loo(LLmat, r_eff = r_eff_mat))
   expect_identical(loo1$estimates, l2$estimates)
@@ -159,7 +163,7 @@ test_that("loo.function runs with multiple cores", {
 })
 
 test_that("save_psis option to loo.function makes correct psis object", {
-  loo_with_fn2 <- loo(llfun, data = data, draws = draws,
+  loo_with_fn2 <- loo.function(llfun, data = data, draws = draws,
                       r_eff = rep(1, nrow(data)), save_psis = TRUE)
   expect_identical(loo_with_fn2$psis_object, loo_with_mat$psis_object)
 })
